@@ -5,6 +5,7 @@ Operations are separated into their own categorized folder.
 from .capabilities.netconf_capabilities import netconf_capabilities
 from .editing.netconf_commit import netconf_commit
 from .editing.netconf_edit_config import netconf_edit_config
+from .editing.netconf_validate import netconf_validate
 from .locking.netconf_lock import netconf_lock
 from .retrieval.netconf_get import netconf_get
 from .retrieval.netconf_get_config import netconf_get_config
@@ -18,4 +19,5 @@ __all__ = (
     "netconf_get_config",
     "netconf_lock",
     "netconf_get_schemas",
+    "netconf_validate",
 )
